@@ -1,5 +1,6 @@
 use crate::sorts::lsb_radix_sort::lsb_radix_sort_adapter;
 use crate::sorts::recombinating_sort::recombinating_sort;
+use crate::sorts::ska_sort::ska_sort_adapter;
 use crate::tuning_parameters::TuningParameters;
 use crate::RadixKey;
 
@@ -17,6 +18,8 @@ pub fn director<T>(
 
     if bucket.len() > len_limit && bucket.len() >= tuning.recombinating_sort_threshold {
         recombinating_sort(tuning, bucket, level);
+    } else if bucket.len() > tuning.ska_sort_threshold {
+        ska_sort_adapter(tuning, bucket, level);
     } else {
         lsb_radix_sort_adapter(bucket, 0, level);
     }
